@@ -1,13 +1,19 @@
 #!/bin/perl
 #
 use Carp;
-use Math::Polynomial::Solve qw(:sturm :utility);
+use Getopt::Long;
+use Math::Polynomial::Solve qw(:sturm :utility ascending_order);
 use Math::Complex;
 use strict;
 use warnings;
 #use IO::Prompt;
 
 my $line;
+my $ascending = 0;
+
+GetOptions('ascending' => \$ascending);
+
+ascending_order($ascending);
 
 while ($line = prompt("Polynomial: ", -num))
 {
@@ -26,7 +32,7 @@ while ($line = prompt("Polynomial: ", -num))
 
 	my $c = 0;
 	$c += abs(fltcmp($_, 0.0)) foreach(@zeros);
-	print "zeros: [", join(", ", @zeros), "]\n";
+	print "zeros at: [", join(", ", @roots), "]\n\n";
 	print "$c non-roots\n" if ($c);
 }
 
